.. py:currentmodule:: NonlinearTMM

TMM
###

Main class
**********

.. autoclass:: NonlinearTMM.TMM
   :members:
   :inherited-members:
   :show-inheritance:

.. autoclass:: NonlinearTMM.NonlinearTMM
   :members:
   :inherited-members:
   :show-inheritance:

Helper classes
**************

.. autoclass:: NonlinearTMM._Intensities
   :members:
   :inherited-members:
   :show-inheritance:

.. autoclass:: NonlinearTMM._SweepResultNonlinearTMM
   :members:
   :inherited-members:
   :show-inheritance:

.. autoclass:: NonlinearTMM._WaveSweepResultNonlinearTMM
   :members:
   :inherited-members:
   :show-inheritance:

.. autoclass:: NonlinearTMM._FieldsZ
   :members:
   :inherited-members:
   :show-inheritance:

.. autoclass:: NonlinearTMM._FieldsZX
   :members:
   :inherited-members:
   :show-inheritance:

.. autoclass:: NonlinearTMM._HomogeneousWave
   :members:
   :inherited-members:
   :show-inheritance:

.. autoclass:: NonlinearTMM._NonlinearLayer
   :members:
   :inherited-members:
   :show-inheritance:

.. autoclass:: NonlinearTMM._Wave
   :members:
   :inherited-members:
   :show-inheritance:
